
SNMP Simulator Control Plane
----------------------------
[![PyPI](https://img.shields.io/pypi/v/snmpsim-control-plane.svg?maxAge=2592000)](https://pypi.org/project/snmpsim-control-plane/)
[![Python Versions](https://img.shields.io/pypi/pyversions/snmpsim-control-plane.svg)](https://pypi.org/project/snmpsim-control-plane/)
[![Build status](https://travis-ci.org/etingof/snmpsim-control-plane.svg?branch=master)](https://travis-ci.org/etingof/snmpsim-control-plane)
[![GitHub license](https://img.shields.io/badge/license-BSD-blue.svg)](https://raw.githubusercontent.com/etingof/snmpsim-control-plane/master/LICENSE.txt)

SNMP Simulator Control Plane is a set of tools facilitating
automated, distributed and remotely controlled
[SNMP Simulator](http://snmplabs.com/snmpsim) deployment.

Features
--------

* Facilitates distributed SNMP Simulator deployment
* Groups simulated SNMP agents into virtual labs
* Makes SNMP simulator remotely controllable
* Collects and serves performance and operational metrics
* REST API is compliant to OpenAPI 3.0.0

Docs & Downloads
----------------

SNMP Simulator Control Plane tool is freely available for download from
[PyPI](https://pypi.org/project/snmpsim-control-plane/) or
[GitHub](https://github.com/etingof/snmpsim-control-plane/archive/master.zip).

User documentation is maintained at [snmplabs.com](http://snmplabs.com/snmpsim-control-plane).

Getting help
------------

If something does not work as expected,
[open an issue](https://github.com/etingof/snmpsim-control-plane/issues) at GitHub or
post your question [on Stack Overflow](https://stackoverflow.com/questions/ask).

Everyone is welcome to fork the repo and propose a feature or a fix!


Copyright (c) 2019-2020, [Ilya Etingof](mailto:etingof@gmail.com). All rights reserved.
